@@ -12,6 +12,7 @@
 #include <cstring>
 #include <list>
 #include <memory>
+#include <new>
 #include <string>
 
 // libwebm common includes.
@@ -26,7 +27,6 @@
 #include "mkvmuxer/mkvmuxer.h"
 #include "mkvmuxer/mkvmuxertypes.h"
 #include "mkvmuxer/mkvwriter.h"
-
 #include "sample_muxer_metadata.h"
 
 namespace {
@@ -723,7 +723,7 @@ int main(int argc, char* argv[]) {
 
           if (frame.len > data_len) {
             delete[] data;
-            data = new unsigned char[frame.len];
+            data = new (std::nothrow) unsigned char[frame.len];
             if (!data)
               return EXIT_FAILURE;
             data_len = frame.len;
